#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.hybrid_shape_interfaces.hybrid_shape_sweep import HybridShapeSweep
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length


class HybridShapeSweepLine(HybridShapeSweep):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.HybridShapeSweep
                |                             HybridShapeSweepLine
                | 
                | Represents the sweep line object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_sweep_line = com_object

    @property
    def angle_law(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AngleLaw() As Reference
                | 
                |     Returns or sets the angular law.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_line.AngleLaw)

    @angle_law.setter
    def angle_law(self, reference_law: Reference):
        """
        :param Reference reference_law:
        """

        self.hybrid_shape_sweep_line.AngleLaw = reference_law.com_object

    @property
    def angle_law_inversion(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AngleLawInversion() As long
                | 
                |     Returns or sets whether the angular law has to be
                |     inverted.
                |     Legal angular law inversion values are:
                |     0 The angular law has NOT to be inverted
                |     1 The angular law has to be inverted

        :rtype: int
        """

        return self.hybrid_shape_sweep_line.AngleLawInversion

    @angle_law_inversion.setter
    def angle_law_inversion(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_line.AngleLawInversion = value

    @property
    def angle_law_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AngleLawType() As long
                | 
                |     Returns or sets the angular law type.
                |     Legal angular law type values are:
                |     0 Undefined law type (CATGSMBasicLawType_None)
                |     1 Constant law type (CATGSMBasicLawType_Constant)
                |     2 Linear law type (CATGSMBasicLawType_Linear)
                |     3 S law type (CATGSMBasicLawType_SType)
                |     4 Law specified by a GSD law feature
                |     (CATGSMBasicLawType_Advanced)

        :rtype: int
        """

        return self.hybrid_shape_sweep_line.AngleLawType

    @angle_law_type.setter
    def angle_law_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_line.AngleLawType = value

    @property
    def canonical_detection(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CanonicalDetection() As long
                | 
                |     Returns or sets whether canonical surfaces of the swept surface are
                |     detected.
                |     Legal values:
                |     0 No detection of canonical surface is performed.
                |     2 Detection of canonical surfaces is performed.

        :rtype: int
        """

        return self.hybrid_shape_sweep_line.CanonicalDetection

    @canonical_detection.setter
    def canonical_detection(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_line.CanonicalDetection = value

    @property
    def context(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Context() As long
                | 
                |     Returns or sets the context on Sweep feature.
                | 
                |         0 This option creates Swept surface.
                |         1 This option creates Swept volume.
                | 
                | 
                |     Note: Setting volume result requires GSO License.
                | 
                |     Example:
                |         This example retrieves in oContext the context for the Sweep hybrid
                |         shape feature.
                | 
                |          Dim oContext
                |          Set oContext = Sweep.Context

        :rtype: int
        """

        return self.hybrid_shape_sweep_line.Context

    @context.setter
    def context(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_line.Context = value

    @property
    def draft_computation_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DraftComputationMode() As long
                | 
                |     Returns or sets the draft computation mode.

        :rtype: int
        """

        return self.hybrid_shape_sweep_line.DraftComputationMode

    @draft_computation_mode.setter
    def draft_computation_mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_line.DraftComputationMode = value

    @property
    def draft_direction(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DraftDirection() As HybridShapeDirection
                | 
                |     Returns or sets the draft direction.
                | 
                |     Example
                |     :
                |         This example retrieves in oDirection the direction of the LinearSweep
                |         feature.
                | 
                |          Dim oDirection As CATIAHybridShapeDirection
                |          Set oDirection = LinearSweep.DraftDirection

        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_sweep_line.DraftDirection)

    @draft_direction.setter
    def draft_direction(self, direction: HybridShapeDirection):
        """
        :param HybridShapeDirection direction:
        """

        self.hybrid_shape_sweep_line.DraftDirection = direction.com_object

    @property
    def first_guide_crv(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstGuideCrv() As Reference
                | 
                |     Returns or sets the sweep operation first guide curve.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_line.FirstGuideCrv)

    @first_guide_crv.setter
    def first_guide_crv(self, reference_curve: Reference):
        """
        :param Reference reference_curve:
        """

        self.hybrid_shape_sweep_line.FirstGuideCrv = reference_curve.com_object

    @property
    def first_guide_surf(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstGuideSurf() As Reference
                | 
                |     Returns or sets the sweep operation first guide surface.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_line.FirstGuideSurf)

    @first_guide_surf.setter
    def first_guide_surf(self, reference_surface: Reference):
        """
        :param Reference reference_surface:
        """

        self.hybrid_shape_sweep_line.FirstGuideSurf = reference_surface.com_object

    @property
    def first_length_law(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstLengthLaw() As Reference
                | 
                |     Returns or sets the first length law useful in some linear sweep types.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_line.FirstLengthLaw)

    @first_length_law.setter
    def first_length_law(self, reference_law: Reference):
        """
        :param Reference reference_law:
        """

        self.hybrid_shape_sweep_line.FirstLengthLaw = reference_law.com_object

    @property
    def first_length_law_inversion(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstLengthLawInversion() As long
                | 
                |     Returns or sets whether the first length law has to be
                |     inverted.
                |     Legal length law inversion values are:
                |     0 The length law has NOT to be inverted
                |     1 The length law has to be inverted

        :rtype: int
        """

        return self.hybrid_shape_sweep_line.FirstLengthLawInversion

    @first_length_law_inversion.setter
    def first_length_law_inversion(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_line.FirstLengthLawInversion = value

    @property
    def guide_deviation(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property GuideDeviation() As Length (Read Only)
                | 
                |     Returns the deviation value (length) from guide curves allowed during a
                |     sweeping operation in order to smooth it.

        :rtype: Length
        """

        return Length(self.hybrid_shape_sweep_line.GuideDeviation)

    @property
    def guide_deviation_activity(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property GuideDeviationActivity() As boolean
                | 
                |     Returns or sets whether a deviation from guide curves is
                |     allowed.
                |     This property gives the information on performing smoothing during sweeping
                |     operation.
                |     TRUE if a deviation from guide curves is allowed, or FALSE otherwise (FALSE
                |     if not specified).

        :rtype: bool
        """

        return self.hybrid_shape_sweep_line.GuideDeviationActivity

    @guide_deviation_activity.setter
    def guide_deviation_activity(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_sweep_line.GuideDeviationActivity = value

    @property
    def mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Mode() As long
                | 
                |     Returns or sets the linear sweep mode.
                |     Legal mode values are:
                |     0 Undefined linear profile swept surface
                |     (CATGSMLinearSweep_None)
                |     1 Linear profile swept surface defined by two guide curves
                |     (CATGSMLinearSweep_TwoGuides)
                |     2 Linear profile swept surface defined by a guide curve and an angle
                |     (CATGSMLinearSweep_GuideAndAngleCurve)
                |     3 Linear profile swept surface defined by a guide curve and a middle curve
                |     (CATGSMLinearSweep_GuideAndMiddle)
                |     4 Linear profile swept surface defined by a guide curve and an angle from
                |     a reference surface
                |     (CATGSMLinearSweep_GuideAndRefSurfaceAngle)
                |     5 Linear profile swept surface defined by a guide curve and a tangency
                |     surface (CATGSMLinearSweep_GuideAndTangencySurface)
                |     6 Linear profile swept surface defined by a guide curve and a draft
                |     directio (CATGSMLinearSweep_GuideAndDraftDirection)
                |     7 Linear profile swept surface defined by two tangency surfaces
                |     (CATGSMLinearSweep_TwoTangencySurfaces)

        :rtype: int
        """

        return self.hybrid_shape_sweep_line.Mode

    @mode.setter
    def mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_line.Mode = value

    @property
    def second_guide_crv(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondGuideCrv() As Reference
                | 
                |     Returns or sets the sweep operation second guide curve.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_line.SecondGuideCrv)

    @second_guide_crv.setter
    def second_guide_crv(self, reference_curve: Reference):
        """
        :param Reference reference_curve:
        """

        self.hybrid_shape_sweep_line.SecondGuideCrv = reference_curve.com_object

    @property
    def second_guide_surf(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondGuideSurf() As Reference
                | 
                |     Returns or sets the sweep operation second guide surface.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_line.SecondGuideSurf)

    @second_guide_surf.setter
    def second_guide_surf(self, reference_surface: Reference):
        """
        :param Reference reference_surface:
        """

        self.hybrid_shape_sweep_line.SecondGuideSurf = reference_surface.com_object

    @property
    def second_length_law(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondLengthLaw() As Reference
                | 
                |     Returns or sets second length law useful in some linear sweep types.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_line.SecondLengthLaw)

    @second_length_law.setter
    def second_length_law(self, reference_law: Reference):
        """
        :param Reference reference_law:
        """

        self.hybrid_shape_sweep_line.SecondLengthLaw = reference_law.com_object

    @property
    def second_length_law_inversion(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondLengthLawInversion() As long
                | 
                |     Returns or sets whether the second length law has to be
                |     inverted.
                |     Legal length law inversion values are:
                |     0 The length law has NOT to be inverted
                |     1 The length law has to be inverted

        :rtype: int
        """

        return self.hybrid_shape_sweep_line.SecondLengthLawInversion

    @second_length_law_inversion.setter
    def second_length_law_inversion(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_line.SecondLengthLawInversion = value

    @property
    def second_trim_option(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondTrimOption() As long
                | 
                |     Returns or sets the trim option for the second tangency
                |     surface.
                | 
                |     Legal trim option values are:
                |     0 No trim computed or trim undefined
                |     (CATGSMSweepTrimMode_None)
                |     1 Trim computed (CATGSMSweepTrimMode_On)

        :rtype: int
        """

        return self.hybrid_shape_sweep_line.SecondTrimOption

    @second_trim_option.setter
    def second_trim_option(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_line.SecondTrimOption = value

    @property
    def smooth_activity(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SmoothActivity() As boolean
                | 
                |     Returns whether the sweeping operation is smoothed.
                |     TRUE if the sweeping operation is smoothed, or FALSE otherwise (FALSE if
                |     not specified).

        :rtype: bool
        """

        return self.hybrid_shape_sweep_line.SmoothActivity

    @smooth_activity.setter
    def smooth_activity(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_sweep_line.SmoothActivity = value

    @property
    def smooth_angle_threshold(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SmoothAngleThreshold() As Angle (Read Only)
                | 
                |     Returns the angular threshold.

        :rtype: Angle
        """

        return Angle(self.hybrid_shape_sweep_line.SmoothAngleThreshold)

    @property
    def solution_no(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SolutionNo() As long
                | 
                |     Returns or sets the choice number, which corresponds to each solution of a
                |     given linear sweep case.
                |     For example: a linear sweep with reference surface leads to four possible
                |     solutions.

        :rtype: int
        """

        return self.hybrid_shape_sweep_line.SolutionNo

    @solution_no.setter
    def solution_no(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_line.SolutionNo = value

    @property
    def spine(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Spine() As Reference
                | 
                |     Returns or sets the sweep operation spine (optional).

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_sweep_line.Spine)

    @spine.setter
    def spine(self, reference_spine: Reference):
        """
        :param Reference reference_spine:
        """

        self.hybrid_shape_sweep_line.Spine = reference_spine.com_object

    @property
    def trim_option(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TrimOption() As long
                | 
                |     Returns or sets the trim option.
                | 
                |     Legal trim option values are:
                |     0 No trim computed or trim undefined
                |     (CATGSMSweepTrimMode_None)
                |     1 Trim computed (CATGSMSweepTrimMode_On)

        :rtype: int
        """

        return self.hybrid_shape_sweep_line.TrimOption

    @trim_option.setter
    def trim_option(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_sweep_line.TrimOption = value

    def add_draft_angle_definition_location(self, ip_ia_loc_elem: Reference, i_ang: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddDraftAngleDefinitionLocation(Reference ipIALocElem,
                | double iAng)
                | 
                |     Adds a draft angle location.
                | 
                |     Parameters:
                | 
                |         ipIALocElem
                |             The geometric element where the draft angle applies
                |             
                |         iAng
                |             The draft angle

        :param Reference ip_ia_loc_elem:
        :param float i_ang:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.AddDraftAngleDefinitionLocation(ip_ia_loc_elem.com_object, i_ang)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_draft_angle_definition_location'
        # # vba_code = """
        # # Public Function add_draft_angle_definition_location(hybrid_shape_sweep_line)
        # #     Dim ipIALocElem (2)
        # #     hybrid_shape_sweep_line.AddDraftAngleDefinitionLocation ipIALocElem
        # #     add_draft_angle_definition_location = ipIALocElem
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_angle(self, i_i: int) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetAngle(long iI) As Angle
                | 
                |     Returns the angle values useful in some linear sweep
                |     types.
                | 
                |     Parameters:
                | 
                |         iI
                |             The angle value index 
                | 
                |     Returns:
                |         The angle value

        :param int i_i:
        :rtype: Angle
        """
        return Angle(self.hybrid_shape_sweep_line.GetAngle(i_i))

    def get_angular_law(self, op_start_ang: Angle, op_end_ang: Angle, o_law_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetAngularLaw(Angle opStartAng,
                | Angle opEndAng,
                | long oLawType)
                | 
                |     Retrieves the angular law useful in some linear sweep
                |     types.
                | 
                |     Parameters:
                | 
                |         opStartAng
                |             The angular law start value 
                |         opEndAng
                |             The angular law end value 
                |         oLawType
                |             The angular law type
                |             Legal angular law type values are:
                |             0 Undefined law type (CATGSMBasicLawType_None)
                |             1 Constant law type (CATGSMBasicLawType_Constant)
                |             2 Linear law type (CATGSMBasicLawType_Linear)
                |             3 S law type (CATGSMBasicLawType_SType)
                |             4 Law specified by a GSD law feature
                |             (CATGSMBasicLawType_Advanced)

        :param Angle op_start_ang:
        :param Angle op_end_ang:
        :param int o_law_type:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetAngularLaw(op_start_ang.com_object, op_end_ang.com_object, o_law_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_angular_law'
        # # vba_code = """
        # # Public Function get_angular_law(hybrid_shape_sweep_line)
        # #     Dim opStartAng (2)
        # #     hybrid_shape_sweep_line.GetAngularLaw opStartAng
        # #     get_angular_law = opStartAng
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_choice_nb_surfaces(self, o_surf_ori1: int, o_surf_ori2: int, o_surf_coupl_ori1: int, o_surf_coupl_ori2: int,
                               o_no: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetChoiceNbSurfaces(long oSurfOri1,
                | long oSurfOri2,
                | long oSurfCouplOri1,
                | long oSurfCouplOri2,
                | long oNo)
                | 
                |     Gets a sequence which identifies a solution amongst all possibilities of a
                |     line-profile swept surface, case
                |     CATGSMLinearSweep_TwoTangencySurfaces.
                | 
                |     Parameters:
                | 
                |         oSurfOri1
                |             This orientation determines the location of the results with regard
                |             to the first surface. Possible values are:
                |             * +1 : the result is in the semi-space defined by the normal to the surface,
                |             * -1 : the result is in the semi-space defined by the opposite to the normal to the
                |                    surface,
                |             * 0 : no orientation is specified, all the results are output,
                |             * 2 : the result changes of semi-space along the spine.
                |         oSurfOri2
                |             This orientation determines the location of the results with regard
                |             to the second surface. Possible values are as for oSurfOri1.
                |             
                |         oSurfCouplOri1
                |             This orientation determines the location of the results with regard
                |             to the trihedron defined by the the spine, the normal to the first surface and
                |             the tangent to the linear profile. Possible values
                |             are:
                |             * +1 : the output results are such that the triedron is counter clockwise,
                |             * -1 : the output results are such that the triedron is clockwise,
                |             * 0 : no orientation is specified, all the results are output,
                |             * 2 : the orientation of the trihedron changes along the spine. 
                |         oSurfCouplOri2
                |             This orientation determines the location of the results with regard
                |             to the trihedron defined by the the spine, the normal to the second surface and
                |             the tangent to the linear profile. Possible values are as for oSurfCouplOri1.
                |             
                |         oNo
                |             Given the previous orientations, solution number in a distance
                |             ordered list.

        :param int o_surf_ori1:
        :param int o_surf_ori2:
        :param int o_surf_coupl_ori1:
        :param int o_surf_coupl_ori2:
        :param int o_no:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetChoiceNbSurfaces(o_surf_ori1, o_surf_ori2, o_surf_coupl_ori1,
                                                                o_surf_coupl_ori2, o_no)

    def get_choice_no(self, o_val1: int, o_val2: int, o_val3: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetChoiceNo(long oVal1,
                | long oVal2,
                | long oVal3)
                | 
                |     Retrieves the choice number associated with each solution of a given linear
                |     sweep case.
                |     Example: a linear sweep with one guide curve and a tangency surface may
                |     lead to several possible solutions.
                | 
                |     Parameters:
                | 
                |         oVal1
                |             The solution number (from 1 to n) 
                |         oVal2
                |             In the example, the shell orientation : -1, +1 or 0 (both +1 and -1) 
                |         val3
                |             In the example, the wire orientation : -1, +1 or 0 (both +1 and -1)

        :param int o_val1:
        :param int o_val2:
        :param int o_val3:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetChoiceNo(o_val1, o_val2, o_val3)

    def get_draft_angle_definition_location(self, i_loc: int, op_ia_element: Reference, o_angle: Angle) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetDraftAngleDefinitionLocation(long iLoc,
                | Reference opIAElement,
                | Angle oAngle)
                | 
                |     Retrieves the draft angle location element.
                | 
                |     Parameters:
                | 
                |         iLoc
                |             The draft angle location position in the list 
                |         opIAElement
                |             The geometric element at that location and where the draft angle
                |             applies 
                |         oAngle
                |             The draft angle

        :param int i_loc:
        :param Reference op_ia_element:
        :param Angle o_angle:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetDraftAngleDefinitionLocation(i_loc, op_ia_element.com_object,
                                                                            o_angle.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_draft_angle_definition_location'
        # # vba_code = """
        # # Public Function get_draft_angle_definition_location(hybrid_shape_sweep_line)
        # #     Dim iLoc (2)
        # #     hybrid_shape_sweep_line.GetDraftAngleDefinitionLocation iLoc
        # #     get_draft_angle_definition_location = iLoc
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_draft_angle_definition_locations_nb(self, o_count: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetDraftAngleDefinitionLocationsNb(long oCount)
                | 
                |     Retrieves the draft angle location list size.
                | 
                |     Parameters:
                | 
                |         oCount
                |             The draft angle location list size

        :param int o_count:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetDraftAngleDefinitionLocationsNb(o_count)

    def get_first_length_definition_type(self, o_first_type: int, op_ia_elem: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetFirstLengthDefinitionType(long oFirstType,
                | Reference opIAElem)
                | 
                |     Retrieves the first length definition type.
                | 
                |     Parameters:
                | 
                |         oFirstType
                |             The first length definition type
                |             Legal length definition types are:
                |             0 Undefined length type
                |             (CATGSMLinearSweepLengthType_None)
                |             1 Length of the swept line in the sweeping plane from the guide
                |             curve (CATGSMLinearSweepLengthType_Standard)
                |             2 No numerical value is required, equivalent to standard length at
                |             zero (CATGSMLinearSweepLengthType_FromCurve)
                |             3 Up to or from a geometrical reference (a surface)
                |             (CATGSMLinearSweepLengthType_Reference)
                |             4 Only for draft surfaces, the length is computed in the draft
                |             direction from an extremum point on the guide curve
                |             (CATGSMLinearSweepLengthType_FromExtremum)
                |             5 Only for draft surfaces, the length will be used in a way
                |             similar to euclidean parallel curve distance on the swept surface
                |             (CATGSMLinearSweepLengthType_AlongSurface)
                |         opIAElem
                |             The geometric element where the first length definition type
                |             applies

        :param int o_first_type:
        :param Reference op_ia_elem:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetFirstLengthDefinitionType(o_first_type, op_ia_elem.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_first_length_definition_type'
        # # vba_code = """
        # # Public Function get_first_length_definition_type(hybrid_shape_sweep_line)
        # #     Dim oFirstType (2)
        # #     hybrid_shape_sweep_line.GetFirstLengthDefinitionType oFirstType
        # #     get_first_length_definition_type = oFirstType
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_first_length_law(self, o_length1: Length, o_length2: Length, o_law_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetFirstLengthLaw(Length oLength1,
                | Length oLength2,
                | long oLawType)
                | 
                |     Retrieves the first length law useful in some linear sweep
                |     types.
                | 
                |     Parameters:
                | 
                |         oLength1
                |             The length law start value 
                |         oLength2
                |             The length law end value 
                |         oLawType
                |             The length law type
                |             Legal length law type values are:
                |             0 Undefined law type (CATGSMBasicLawType_None)
                |             1 Constant law type (CATGSMBasicLawType_Constant)
                |             2 Linear law type (CATGSMBasicLawType_Linear)
                |             3 S law type (CATGSMBasicLawType_SType)
                |             4 Law specified by a GSD law feature
                |             (CATGSMBasicLawType_Advanced)

        :param Length o_length1:
        :param Length o_length2:
        :param int o_law_type:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetFirstLengthLaw(o_length1.com_object, o_length2.com_object, o_law_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_first_length_law'
        # # vba_code = """
        # # Public Function get_first_length_law(hybrid_shape_sweep_line)
        # #     Dim oLength1 (2)
        # #     hybrid_shape_sweep_line.GetFirstLengthLaw oLength1
        # #     get_first_length_law = oLength1
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_length(self, i_i: int) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetLength(long iI) As Length
                | 
                |     Returns the length values useful in some linear sweep
                |     types.
                | 
                |     Parameters:
                | 
                |         iI
                |             The length value index 
                | 
                |     Returns:
                |         The length value

        :param int i_i:
        :rtype: Length
        """
        return Length(self.hybrid_shape_sweep_line.GetLength(i_i))

    def get_length_law_types(self, o_first_type: int, o_second_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetLengthLawTypes(long oFirstType,
                | long oSecondType)
                | 
                |     Gets length law types.
                | 
                |     Parameters:
                | 
                |         oFirstType
                |             First type of law. 
                |         oSecondType
                |             Second type of law. oFirstType and oSecondType
                |             0 : Undefined law type
                |             1 : Constant law type
                |             2 : Linear law type
                |             3 : S law type
                |             4 : Law specified by a GSD law feature
                |             5 : Law specified by a set of points and parameters

        :param int o_first_type:
        :param int o_second_type:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetLengthLawTypes(o_first_type, o_second_type)

    def get_longitudinal_relimiters(self, op_ia_elem1: Reference, op_ia_elem2: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetLongitudinalRelimiters(Reference opIAElem1,
                | Reference opIAElem2)
                | 
                |     Deprecated:
                |         V5R16 CATHybridShapeSweepLine#GetRelimiters Retrieves the elements
                |         relimiting the spine (or the default spine). 
                |     Parameters:
                | 
                |         opIAElem1
                |             The first relimiting feature (plane or point) 
                |         opIAElem2
                |             The second relimiting feature (plane or point)

        :param Reference op_ia_elem1:
        :param Reference op_ia_elem2:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetLongitudinalRelimiters(op_ia_elem1.com_object, op_ia_elem2.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_longitudinal_relimiters'
        # # vba_code = """
        # # Public Function get_longitudinal_relimiters(hybrid_shape_sweep_line)
        # #     Dim opIAElem1 (2)
        # #     hybrid_shape_sweep_line.GetLongitudinalRelimiters opIAElem1
        # #     get_longitudinal_relimiters = opIAElem1
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_nb_angle(self, o_ang: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetNbAngle(long oAng)
                | 
                |     Retrieves the number of angles.
                | 
                |     Parameters:
                | 
                |         oAng
                |             The number of angles

        :param int o_ang:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetNbAngle(o_ang)

    def get_nb_guide_crv(self, o_num: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetNbGuideCrv(long oNum)
                | 
                |     Retrieves the number of guides curves.
                | 
                |     Parameters:
                | 
                |         oNum
                |             The number of guide curves

        :param int o_num:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetNbGuideCrv(o_num)

    def get_nb_guide_sur(self, o_num: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetNbGuideSur(long oNum)
                | 
                |     Retrieves the number of guide surfaces.
                | 
                |     Parameters:
                | 
                |         oNum
                |             The number of guides surfaces

        :param int o_num:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetNbGuideSur(o_num)

    def get_nb_length(self, o_len: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetNbLength(long oLen)
                | 
                |     Retrieves the number of lengths.
                | 
                |     Parameters:
                | 
                |         oLen
                |             The number of lengths

        :param int o_len:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetNbLength(o_len)

    def get_relimiters(self, op_ia_elem1: Reference, op_orient1: int, op_ia_elem2: Reference, op_orient2: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetRelimiters(Reference opIAElem1,
                | long opOrient1,
                | Reference opIAElem2,
                | long opOrient2)
                | 
                |     Retrieves the elements relimiting the spine (or the default
                |     spine).
                | 
                |     Parameters:
                | 
                |         opIAElem1
                |             The first relimiting feature (plane or point) 
                |         opOrient1
                |             Split direction for the first relimitation
                |             0 means that the beginning of the spine (considering its
                |             orientation) is removed, 1 means that the end of the spine is removed
                |             
                |         opIAElem2
                |             The second relimiting feature (plane or point) 
                |         opOrient2
                |             Split direction for the second relimitation

        :param Reference op_ia_elem1:
        :param int op_orient1:
        :param Reference op_ia_elem2:
        :param int op_orient2:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetRelimiters(op_ia_elem1.com_object, op_orient1, op_ia_elem2.com_object,
                                                          op_orient2)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_relimiters'
        # # vba_code = """
        # # Public Function get_relimiters(hybrid_shape_sweep_line)
        # #     Dim opIAElem1 (2)
        # #     hybrid_shape_sweep_line.GetRelimiters opIAElem1
        # #     get_relimiters = opIAElem1
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_second_length_definition_type(self, o_second_type: int, op_ia_elem: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetSecondLengthDefinitionType(long oSecondType,
                | Reference opIAElem)
                | 
                |     Retrieves the second length definition type.
                | 
                |     Parameters:
                | 
                |         oSecondType
                |             The second length definition type
                |             Legal length definition types are:
                |             0 Undefined length type
                |             (CATGSMLinearSweepLengthType_None)
                |             1 Length of the swept line in the sweeping plane from the guide
                |             curve (CATGSMLinearSweepLengthType_Standard)
                |             2 No numerical value is required, equivalent to standard length at
                |             zero (CATGSMLinearSweepLengthType_FromCurve)
                |             3 Up to or from a geometrical reference (a surface)
                |             (CATGSMLinearSweepLengthType_Reference)
                |             4 Only for draft surfaces, the length is computed in the draft
                |             direction from an extremum point on the guide curve
                |             (CATGSMLinearSweepLengthType_FromExtremum)
                |             5 Only for draft surfaces, the length will be used in a way
                |             similar to euclidean parallel curve distance on the swept surface
                |             (CATGSMLinearSweepLengthType_AlongSurface)
                |         opIAElem
                |             The geometric element where the second length definition type
                |             applies

        :param int o_second_type:
        :param Reference op_ia_elem:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetSecondLengthDefinitionType(o_second_type, op_ia_elem.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_second_length_definition_type'
        # # vba_code = """
        # # Public Function get_second_length_definition_type(hybrid_shape_sweep_line)
        # #     Dim oSecondType (2)
        # #     hybrid_shape_sweep_line.GetSecondLengthDefinitionType oSecondType
        # #     get_second_length_definition_type = oSecondType
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_second_length_law(self, o_length1: Length, o_length2: Length, o_law_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetSecondLengthLaw(Length oLength1,
                | Length oLength2,
                | long oLawType)
                | 
                |     Retrieves the second length law useful in some linear sweep
                |     types.
                | 
                |     Parameters:
                | 
                |         oLength1
                |             The length law start value 
                |         oLength2
                |             The length law end value 
                |         oLawType
                |             The length law type
                |             Legal length law type values are:
                |             0 Undefined law type (CATGSMBasicLawType_None)
                |             1 Constant law type (CATGSMBasicLawType_Constant)
                |             2 Linear law type (CATGSMBasicLawType_Linear)
                |             3 S law type (CATGSMBasicLawType_SType)
                |             4 Law specified by a GSD law feature
                |             (CATGSMBasicLawType_Advanced)

        :param Length o_length1:
        :param Length o_length2:
        :param int o_law_type:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.GetSecondLengthLaw(o_length1.com_object, o_length2.com_object, o_law_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_second_length_law'
        # # vba_code = """
        # # Public Function get_second_length_law(hybrid_shape_sweep_line)
        # #     Dim oLength1 (2)
        # #     hybrid_shape_sweep_line.GetSecondLengthLaw oLength1
        # #     get_second_length_law = oLength1
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def insert_draft_angle_definition_location(self, i_elem: Reference, i_angle: Angle, i_pos: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InsertDraftAngleDefinitionLocation(Reference iElem,
                | Angle iAngle,
                | long iPos)
                | 
                |     Inserts a geometrical element and a value necessary for draft angle
                |     definition after a given position in the lists.
                | 
                |     Parameters:
                | 
                |         iElem
                |             Geometrical element 
                |         iAngle
                |             Angular parameter 
                |         iPos
                |             Position in lists. To insert in the beginning of the list put iPos = 0.

        :param Reference i_elem:
        :param Angle i_angle:
        :param int i_pos:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.InsertDraftAngleDefinitionLocation(i_elem.com_object, i_angle.com_object,
                                                                               i_pos)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'insert_draft_angle_definition_location'
        # # vba_code = """
        # # Public Function insert_draft_angle_definition_location(hybrid_shape_sweep_line)
        # #     Dim iElem (2)
        # #     hybrid_shape_sweep_line.InsertDraftAngleDefinitionLocation iElem
        # #     insert_draft_angle_definition_location = iElem
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_all_draft_angle_definition_locations(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveAllDraftAngleDefinitionLocations()
                | 
                |     Removes all geometrical elements and values necessary for draft angle
                |     definition.

        :rtype: None
        """
        return self.hybrid_shape_sweep_line.RemoveAllDraftAngleDefinitionLocations()

    def remove_angle(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveAngle()
                | 
                |     Removes an angle.

        :rtype: None
        """
        return self.hybrid_shape_sweep_line.RemoveAngle()

    def remove_draft_angle_definition_location_position(self, i_pos: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveDraftAngleDefinitionLocationPosition(long iPos)
                | 
                |     Removes a draft angle location.
                | 
                |     Parameters:
                | 
                |         iPos
                |             The position in the list of the draft angle location to
                |             remove

        :param int i_pos:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.RemoveDraftAngleDefinitionLocationPosition(i_pos)

    def remove_guide_crv(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveGuideCrv()
                | 
                |     Removes a guide curve.

        :rtype: None
        """
        return self.hybrid_shape_sweep_line.RemoveGuideCrv()

    def remove_guide_sur(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveGuideSur()
                | 
                |     Removes a guide surface.

        :rtype: None
        """
        return self.hybrid_shape_sweep_line.RemoveGuideSur()

    def remove_length(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveLength()
                | 
                |     Removes a length.

        :rtype: None
        """
        return self.hybrid_shape_sweep_line.RemoveLength()

    def set_angle(self, i_i: int, i_elem: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetAngle(long iI,
                | double iElem)
                | 
                |     Sets the angle values useful in some linear sweep types.
                | 
                |     Parameters:
                | 
                |         iI
                |             The angle value index 
                |         iElem
                |             The angle value

        :param int i_i:
        :param float i_elem:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetAngle(i_i, i_elem)

    def set_angular_law(self, i_start_ang: float, i_end_ang: float, i_law_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetAngularLaw(double iStartAng,
                | double iEndAng,
                | long iLawType)
                | 
                |     Sets the angular law useful in some linear sweep types.
                | 
                |     Parameters:
                | 
                |         iStartAng
                |             The angular law start value 
                |         iEndAng
                |             The angular law end value 
                |         iLawType
                |             The angular law type
                |             Legal angular law type values are:
                |             0 Undefined law type (CATGSMBasicLawType_None)
                |             1 Constant law type (CATGSMBasicLawType_Constant)
                |             2 Linear law type (CATGSMBasicLawType_Linear)
                |             3 S law type (CATGSMBasicLawType_SType)
                |             4 Law specified by a GSD law feature
                |             (CATGSMBasicLawType_Advanced)

        :param float i_start_ang:
        :param float i_end_ang:
        :param int i_law_type:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetAngularLaw(i_start_ang, i_end_ang, i_law_type)

    def set_choice_nb_surfaces(self, i_surf_ori1: int, i_surf_ori2: int, i_surf_coupl_ori1: int, i_surf_coupl_ori2: int,
                               i_no: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetChoiceNbSurfaces(long iSurfOri1,
                | long iSurfOri2,
                | long iSurfCouplOri1,
                | long iSurfCouplOri2,
                | long iNo)
                | 
                |     Sets a sequence which identifies a solution amongst all possibilities of a
                |     line-profile swept surface, case
                |     CATGSMLinearSweep_TwoTangencySurfaces.
                | 
                |     Parameters:
                | 
                |         iSurfOri1
                |             This orientation determines the location of the results with regard
                |             to the first surface. Possible values are:
                |             * +1 : the result is in the semi-space defined by the normal to the surface,
                |             * -1 : the result is in the semi-space defined by the opposite to the normal to the ,
                |             * 0 : no orientation is specified, all the results are output,
                |             * 2 : the result changes of semi-space along the spine.
                |         iSurfOri2
                |             This orientation determines the location of the results with regard
                |             to the second surface. Possible values are as for iSurfOri1.
                |             
                |         iSurfCouplOri1
                |             This orientation determines the location of the results with regard
                |             to the trihedron defined by the the spine, the normal to the first surface and
                |             the tangent to the linear profile. Possible values
                |             are:
                |             * +1 : the output results are such that the triedron is counter clockwise,
                |             * -1 : the output results are such that the triedron is clockwise,
                |             * 0 : no orientation is specified, all the results are output,
                |             * 2 : the orientation of the trihedron changes along the spine. 
                |         iSurfCouplOri2
                |             This orientation determines the location of the results with regard
                |             to the trihedron defined by the the spine, the normal to the second surface and
                |             the tangent to the linear profile. Possible values are as for iSurfCouplOri2.
                |             
                |         iNo
                |             Given the previous orientations, solution number in a distance
                |             ordered list.

        :param int i_surf_ori1:
        :param int i_surf_ori2:
        :param int i_surf_coupl_ori1:
        :param int i_surf_coupl_ori2:
        :param int i_no:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetChoiceNbSurfaces(i_surf_ori1, i_surf_ori2, i_surf_coupl_ori1,
                                                                i_surf_coupl_ori2, i_no)

    def set_choice_no(self, i_val1: int, i_val2: int, i_val3: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetChoiceNo(long iVal1,
                | long iVal2,
                | long iVal3)
                | 
                |     Sets the choice number associated with each solution of a given linear
                |     sweep case.
                |     Example: a linear sweep with one guide curve and a tangency surface may
                |     lead to several possible solutions.
                | 
                |     Parameters:
                | 
                |         iVal1
                |             The solution number (from 1 to n) 
                |         iVal2
                |             In the example, the shell orientation : -1, +1 or 0 (both +1 and -1) 
                |         iVal3
                |             In the example, the wire orientation : -1, +1 or 0 (both +1 and -1)

        :param int i_val1:
        :param int i_val2:
        :param int i_val3:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetChoiceNo(i_val1, i_val2, i_val3)

    def set_first_length_definition_type(self, i_first_type: int, ip_ia_elem: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetFirstLengthDefinitionType(long iFirstType,
                | Reference ipIAElem)
                | 
                |     Sets the first length definition type.
                | 
                |     Parameters:
                | 
                |         iFirstType
                |             The first length definition type
                |             Legal length definition types are:
                |             0 Undefined length type
                |             (CATGSMLinearSweepLengthType_None)
                |             1 Length of the swept line in the sweeping plane from the guide
                |             curve (CATGSMLinearSweepLengthType_Standard)
                |             2 No numerical value is required, equivalent to standard length at
                |             zero (CATGSMLinearSweepLengthType_FromCurve)
                |             3 Up to or from a geometrical reference (a surface)
                |             (CATGSMLinearSweepLengthType_Reference)
                |             4 Only for draft surfaces, the length is computed in the draft
                |             direction from an extremum point on the guide curve
                |             (CATGSMLinearSweepLengthType_FromExtremum)
                |             5 Only for draft surfaces, the length will be used in a way
                |             similar to euclidean parallel curve distance on the swept surface
                |             (CATGSMLinearSweepLengthType_AlongSurface)
                |         ipIAElem
                |             The geometric element where the first length definition type
                |             applies

        :param int i_first_type:
        :param Reference ip_ia_elem:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetFirstLengthDefinitionType(i_first_type, ip_ia_elem.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_first_length_definition_type'
        # # vba_code = """
        # # Public Function set_first_length_definition_type(hybrid_shape_sweep_line)
        # #     Dim iFirstType (2)
        # #     hybrid_shape_sweep_line.SetFirstLengthDefinitionType iFirstType
        # #     set_first_length_definition_type = iFirstType
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_first_length_law(self, i_length1: float, i_length2: float, i_law_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetFirstLengthLaw(double iLength1,
                | double iLength2,
                | long iLawType)
                | 
                |     Sets the first length law useful in some linear sweep
                |     types.
                | 
                |     Parameters:
                | 
                |         iLength1
                |             The length law start value 
                |         iLength2
                |             The length law end value 
                |         iLawType
                |             The length law type
                |             Legal length law type values are:
                |             0 Undefined law type (CATGSMBasicLawType_None)
                |             1 Constant law type (CATGSMBasicLawType_Constant)
                |             2 Linear law type (CATGSMBasicLawType_Linear)
                |             3 S law type (CATGSMBasicLawType_SType)
                |             4 Law specified by a GSD law feature
                |             (CATGSMBasicLawType_Advanced)

        :param float i_length1:
        :param float i_length2:
        :param int i_law_type:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetFirstLengthLaw(i_length1, i_length2, i_law_type)

    def set_guide_deviation(self, i_length: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetGuideDeviation(double iLength)
                | 
                |     Sets the deviation value (length) from guide curves allowed during sweeping
                |     operation in order to smooth it.
                | 
                |     Parameters:
                | 
                |         iLength
                |             The deviation value

        :param float i_length:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetGuideDeviation(i_length)

    def set_length(self, i_i: int, i_elem: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLength(long iI,
                | double iElem)
                | 
                |     Sets the linear values useful in some linear sweep types.
                | 
                |     Parameters:
                | 
                |         iI
                |             The linear value index 
                |         iElem
                |             The linear value

        :param int i_i:
        :param float i_elem:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetLength(i_i, i_elem)

    def set_length_law_types(self, i_first_type: int, i_second_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLengthLawTypes(long iFirstType,
                | long iSecondType)
                | 
                |     Sets length law types.
                | 
                |     Parameters:
                | 
                |         iFirstType
                |             First type of law. 
                |         iSecondType
                |             Second type of law. iFirstType and iSecondType
                |             0 : Undefined law type
                |             1 : Constant law type
                |             2 : Linear law type
                |             3 : S law type
                |             4 : Law specified by a GSD law feature
                |             5 : Law specified by a set of points and parameters

        :param int i_first_type:
        :param int i_second_type:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetLengthLawTypes(i_first_type, i_second_type)

    def set_longitudinal_relimiters(self, ip_ia_elem1: Reference, ip_ia_elem2: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLongitudinalRelimiters(Reference ipIAElem1,
                | Reference ipIAElem2)
                | 
                |     Deprecated:
                |         V5R16 CATHybridShapeSweepLine#SetRelimiters Sets the elements
                |         relimiting the spine (or the default spine). 
                |     Parameters:
                | 
                |         ipIAElem1
                |             The first relimiting feature (plane or point) 
                |         ipIAElem2
                |             The second relimiting feature (plane or point)

        :param Reference ip_ia_elem1:
        :param Reference ip_ia_elem2:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetLongitudinalRelimiters(ip_ia_elem1.com_object, ip_ia_elem2.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_longitudinal_relimiters'
        # # vba_code = """
        # # Public Function set_longitudinal_relimiters(hybrid_shape_sweep_line)
        # #     Dim ipIAElem1 (2)
        # #     hybrid_shape_sweep_line.SetLongitudinalRelimiters ipIAElem1
        # #     set_longitudinal_relimiters = ipIAElem1
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_relimiters(self, ip_ia_elem1: Reference, ip_orient1: int, ip_ia_elem2: Reference, ip_orient2: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetRelimiters(Reference ipIAElem1,
                | long ipOrient1,
                | Reference ipIAElem2,
                | long ipOrient2)
                | 
                |     Sets the elements relimiting the spine (or the default
                |     spine).
                | 
                |     Parameters:
                | 
                |         ipIAElem1
                |             The first relimiting feature (plane or point) 
                |         ipOrient1
                |             Split direction for the first relimitation
                |             0 means that the beginning of the spine (considering its
                |             orientation) is removed, 1 means that the end of the spine is removed
                |             
                |         ipIAElem2
                |             The second relimiting feature (plane or point) 
                |         ipOrient2
                |             Split direction for the second relimitation

        :param Reference ip_ia_elem1:
        :param int ip_orient1:
        :param Reference ip_ia_elem2:
        :param int ip_orient2:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetRelimiters(ip_ia_elem1.com_object, ip_orient1, ip_ia_elem2.com_object,
                                                          ip_orient2)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_relimiters'
        # # vba_code = """
        # # Public Function set_relimiters(hybrid_shape_sweep_line)
        # #     Dim ipIAElem1 (2)
        # #     hybrid_shape_sweep_line.SetRelimiters ipIAElem1
        # #     set_relimiters = ipIAElem1
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_second_length_definition_type(self, i_second_type: int, ip_ia_elem: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSecondLengthDefinitionType(long iSecondType,
                | Reference ipIAElem)
                | 
                |     Sets the second length definition type.
                | 
                |     Parameters:
                | 
                |         iSecondType
                |             The second length definition type
                |             Legal length definition types are:
                |             0 Undefined length type
                |             (CATGSMLinearSweepLengthType_None)
                |             1 Length of the swept line in the sweeping plane from the guide
                |             curve (CATGSMLinearSweepLengthType_Standard)
                |             2 No numerical value is required, equivalent to standard length at
                |             zero (CATGSMLinearSweepLengthType_FromCurve)
                |             3 Up to or from a geometrical reference (a surface)
                |             (CATGSMLinearSweepLengthType_Reference)
                |             4 Only for draft surfaces, the length is computed in the draft
                |             direction from an extremum point on the guide curve
                |             (CATGSMLinearSweepLengthType_FromExtremum)
                |             5 Only for draft surfaces, the length will be used in a way
                |             similar to euclidean parallel curve distance on the swept surface
                |             (CATGSMLinearSweepLengthType_AlongSurface)
                |         ipIAElem
                |             The geometric element where the second length definition type
                |             applies

        :param int i_second_type:
        :param Reference ip_ia_elem:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetSecondLengthDefinitionType(i_second_type, ip_ia_elem.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_second_length_definition_type'
        # # vba_code = """
        # # Public Function set_second_length_definition_type(hybrid_shape_sweep_line)
        # #     Dim iSecondType (2)
        # #     hybrid_shape_sweep_line.SetSecondLengthDefinitionType iSecondType
        # #     set_second_length_definition_type = iSecondType
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_second_length_law(self, i_length1: float, i_length2: float, i_law_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSecondLengthLaw(double iLength1,
                | double iLength2,
                | long iLawType)
                | 
                |     Sets the second length law useful in some linear sweep
                |     types.
                | 
                |     Parameters:
                | 
                |         iLength1
                |             The length law start value 
                |         iLength2
                |             The length law end value 
                |         iLawType
                |             The length law type
                |             Legal length law type values are:
                |             0 Undefined law type (CATGSMBasicLawType_None)
                |             1 Constant law type (CATGSMBasicLawType_Constant)
                |             2 Linear law type (CATGSMBasicLawType_Linear)
                |             3 S law type (CATGSMBasicLawType_SType)
                |             4 Law specified by a GSD law feature
                |             (CATGSMBasicLawType_Advanced)

        :param float i_length1:
        :param float i_length2:
        :param int i_law_type:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetSecondLengthLaw(i_length1, i_length2, i_law_type)

    def set_smooth_angle_threshold(self, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSmoothAngleThreshold(double iAngle)
                | 
                |     Sets the angular threshold.
                | 
                |     Parameters:
                | 
                |         iAngle
                |             The angle numerical value

        :param float i_angle:
        :rtype: None
        """
        return self.hybrid_shape_sweep_line.SetSmoothAngleThreshold(i_angle)

    def __repr__(self):
        return f'HybridShapeSweepLine(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_igp_setup_interfaces.device_task import DeviceTask
from pycatia.system_interfaces.any_object import AnyObject


class DeviceTaskFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DeviceTaskFactory
                | 
                | Represents the Task Creation Factory for Devices.
                | 
                | Role: Device Task Factory is the object used to create Device
                | tasks.
                | The following code snippet can be used to obtain the Device Task Factory from
                | the Device product.
                | 
                |    Dim objDeviceTaskFactory As DeviceTaskFactory
                |    Dim objDevice As Product
                |    ...
                |    Set objDeviceTaskFactory = objDevice.GetTechnologicalObject("DeviceTaskFactory" )
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.device_task_factory = com_object

    def create_device_task(self, i_name: str, o_device_task: DeviceTask) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateDeviceTask(CATBSTR iName,
                | DeviceTask oDeviceTask)
                | 
                |     Creates a Device Task
                | 
                |     Parameters:
                | 
                |         iName
                |             The Device Task Name. 
                |         oDeviceTask
                |             The Created Device Task. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Device Task was successfully created.
                |         E_FAIL
                |             The Device Task creation failed.
                | 
                |         Example:
                |             The following example creates a Device task for a
                |             Device.
                | 
                |                Dim objDeviceTaskFactory As DeviceTaskFactory
                |                Dim objDeviceTask as DeviceTask
                |                ..
                |                objDeviceTaskFactory.CreateDeviceTask
                |                "New_DeviceTask_1",objDeviceTask

        :param str i_name:
        :param DeviceTask o_device_task:
        :rtype: None
        """
        return self.device_task_factory.CreateDeviceTask(i_name, o_device_task.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_device_task'
        # # vba_code = """
        # # Public Function create_device_task(device_task_factory)
        # #     Dim iName (2)
        # #     device_task_factory.CreateDeviceTask iName
        # #     create_device_task = iName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def delete_device_task(self, i_device_task: DeviceTask) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DeleteDeviceTask(DeviceTask iDeviceTask)
                | 
                |     Removes the required Device Task.
                | 
                |     Parameters:
                | 
                |         iDeviceTask
                |             The Device Task to be Removed. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Device Task could be successfully deleted.
                |         E_FAIL
                |             The deletion of Device Task failed.
                | 
                |         Example:
                |             The following example deletes a device task.
                | 
                |                Dim objDeviceTaskFactory As DeviceTaskFactory
                |                Dim objDeviceTask as DeviceTask
                |                ..
                |                objRobotTaskFactory.DeleteDeviceTask
                |                objDeviceTask

        :param DeviceTask i_device_task:
        :rtype: None
        """
        return self.device_task_factory.DeleteDeviceTask(i_device_task.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete_device_task'
        # # vba_code = """
        # # Public Function delete_device_task(device_task_factory)
        # #     Dim iDeviceTask (2)
        # #     device_task_factory.DeleteDeviceTask iDeviceTask
        # #     delete_device_task = iDeviceTask
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_all_device_tasks(self, o_robot_task_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAllDeviceTasks(CATSafeArrayVariant oRobotTaskList)
                | 
                |     Retrieves the list of Device tasks.
                | 
                |     Parameters:
                | 
                |         oDeviceTaskList
                |             The Device Task List. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Device Task List could be successfully
                |             queried.
                |         E_FAIL
                |             The Device Task List could not be retrieved.
                | 
                |         Example:
                |             The following example Retrieves the list of Device Tasks for the
                |             Device.
                | 
                |                Dim objDeviceTaskFactory As DeviceTaskFactory
                |                Dim objDeviceTask(3) as DeviceTask
                |                ..
                |                objDeviceTaskFactory.GetAllDeviceTasks
                |                objDeviceTask

        :param tuple o_robot_task_list:
        :rtype: None
        """
        return self.device_task_factory.GetAllDeviceTasks(o_robot_task_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_all_device_tasks'
        # # vba_code = """
        # # Public Function get_all_device_tasks(device_task_factory)
        # #     Dim oRobotTaskList (2)
        # #     device_task_factory.GetAllDeviceTasks oRobotTaskList
        # #     get_all_device_tasks = oRobotTaskList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DeviceTaskFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_boundary_condition import ABQBoundaryCondition
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQBoundaryConditions(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQBoundaryConditions
                | 
                | The collection of Abaqus boundary condition objects attached
                | to
                | ABQGeneralStaticStep, ABQHeatTransferStep, and ABQExplicitDynamicsStep
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ABQBoundaryCondition)
        self.abq_boundary_conditions = com_object

    def add(self, i_boundary_type: str) -> ABQBoundaryCondition:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(CATBSTR iBoundaryType) As ABQBoundaryCondition
                | 
                |     Creates a new Abaqus boundary condition and adds it to the collection of
                |     Abaqus boundary conditions.
                | 
                |     Parameters:
                | 
                |         iBoundaryType
                |             The type of the boundary condition to create.
                | 
                |             Legal values:
                | 
                |             "ABQClamp"
                |             "ABQDisplacementBC"
                |             "ABQTemperatureBC"
                | 
                |     Returns:
                |         oBoundaryCondition The Abaqus boundary condition object that was
                |         created. 
                |     Example:
                |         The following example creates a clamp boundary condition in the
                |         ABQBoundaryConditions collection:
                | 
                |          Dim abaqusBCs As ABQBoundaryConditions
                |          Dim abqClampBC As ABQClampBC
                |          Set abqClampBC =  abaqusBCs.Add("ABQClamp")

        :param str i_boundary_type:
        :rtype: ABQBoundaryCondition
        """
        return ABQBoundaryCondition(self.abq_boundary_conditions.Add(i_boundary_type))

    def item(self, i_index: cat_variant) -> ABQBoundaryCondition:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ABQBoundaryCondition
                | 
                |     Returns an Abaqus boundary condition using its index or its name from the
                |     ABQBoundaryConditions collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus boundary condition to retrieve
                |             from the collection of Abaqus boundary conditions. If the index is a number, it
                |             specifies the rank of the Abaqus boundary condition in the collection. The
                |             index of the first Abaqus boundary condition in the collection is 1, and the
                |             index of the last boundary condition is Count. If the index is a string, it
                |             specifies the name you assigned to the boundary condition using the
                |             CATIACollection::Name property. 
                | 
                |     Returns:
                |         The specified ABQBoundaryCondition.

        :param cat_variant i_index:
        :rtype: ABQBoundaryCondition
        """
        return ABQBoundaryCondition(self.abq_boundary_conditions.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes an Abaqus boundary condition using its index or its name from the
                |     collection of boundary conditions.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus boundary condition to retrieve
                |             from the collection of Abaqus boundary conditions. If the index is a number, it
                |             specifies the rank of the Abaqus boundary condition in the collection. The
                |             index of the first Abaqus boundary condition in the collection is 1, and the
                |             index of the last boundary condition is Count. If the index is a string, it
                |             specifies the name you assigned to the boundary condition using the
                |             CATIACollection::Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.abq_boundary_conditions.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(abq_boundary_conditions)
        # #     Dim iIndex (2)
        # #     abq_boundary_conditions.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQBoundaryConditions(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_doubles import SchListOfDoubles
from pycatia.system_interfaces.any_object import AnyObject


class SchGRRComp(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchGRRComp
                | 
                | Manage the graphical representation of a schematic component.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_grr_comp = com_object

    def get_position(self, o_db2_position: SchListOfDoubles) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPosition(SchListOfDoubles oDb2Position)
                | 
                |     Get the current position of the component.
                | 
                |     Parameters:
                | 
                |         oDb2Position
                |             The current position of the component. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRComp
                |          Dim objArg1 As SchListOfDoubles
                |           ...
                |          objThisIntf.GetPositionobjArg1

        :param SchListOfDoubles o_db2_position:
        :rtype: None
        """
        return self.sch_grr_comp.GetPosition(o_db2_position.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_position'
        # # vba_code = """
        # # Public Function get_position(sch_grr_comp)
        # #     Dim oDb2Position (2)
        # #     sch_grr_comp.GetPosition oDb2Position
        # #     get_position = oDb2Position
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_rotation_angle(self, o_db1_rotation_angle_in_rad: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetRotationAngle(double oDb1RotationAngleInRad)
                | 
                |     Get the current rotation angle (from x-axis in radian) of the
                |     component.
                | 
                |     Parameters:
                | 
                |         oDb1RotationAngleInRad
                |             The current angle of the component in radian. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRComp
                |          Dim dbVar As Double;
                |           ...
                |          objThisIntf.GetRotationAngledbVar

        :param float o_db1_rotation_angle_in_rad:
        :rtype: None
        """
        return self.sch_grr_comp.GetRotationAngle(o_db1_rotation_angle_in_rad)

    def get_scale(self, o_db1_scale_factor: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetScale(double oDb1ScaleFactor)
                | 
                |     Get the current scale factor of the component.
                | 
                |     Parameters:
                | 
                |         oDb1ScaleFactor
                |             The current scale factor of the component. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRComp
                |          Dim dbVar As Double;
                |           ...
                |          objThisIntf.GetScaledbVar

        :param float o_db1_scale_factor:
        :rtype: None
        """
        return self.sch_grr_comp.GetScale(o_db1_scale_factor)

    def get_transformation2_d(self, o_db6_trans_matrix: SchListOfDoubles) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTransformation2D(SchListOfDoubles oDb6TransMatrix)
                | 
                |     Get the local coordinate reference frame (with respect to absolute
                |     coordinate system) of the component.
                | 
                |     Parameters:
                | 
                |         oDb6TransMatrix
                |             An double array of 6 members. Transformation matrix that defines
                |             the local coordinate reference frame of the component member 1, 2 - defines the
                |             x-axis of the local coordinate reference frame. member 3, 4 - defines the
                |             y-axis of the local coordinate reference frame. member 5, 6 - defines the
                |             origin of the local coordinate reference frame One can also interpret this as
                |             the transformation matrix that would move the component from the absolute
                |             coordinate frame to the current position and orientation. As such, the member
                |             5,6 define the translational vector Furthemore, rotation angle and scale factor
                |             can be calculated from member 1 to 4. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRComp
                |          Dim objArg1 As SchListOfDoubles
                |           ...
                |          objThisIntf.GetTransformation2DobjArg1

        :param SchListOfDoubles o_db6_trans_matrix:
        :rtype: None
        """
        return self.sch_grr_comp.GetTransformation2D(o_db6_trans_matrix.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_transformation2_d'
        # # vba_code = """
        # # Public Function get_transformation2_d(sch_grr_comp)
        # #     Dim oDb6TransMatrix (2)
        # #     sch_grr_comp.GetTransformation2D oDb6TransMatrix
        # #     get_transformation2_d = oDb6TransMatrix
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_position(self, o_db2_position: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPosition(CATSafeArrayVariant oDb2Position)
                | 
                |     Set the current position of the component.
                | 
                |     Parameters:
                | 
                |         iDb2Position
                |             The position of the component to be set. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRComp
                |          Dim dbVar1(x) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.SetPositiondbVar1

        :param tuple o_db2_position:
        :rtype: tuple
        """
        return self.sch_grr_comp.SetPosition(o_db2_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_position'
        # # vba_code = """
        # # Public Function set_position(sch_grr_comp)
        # #     Dim oDb2Position (2)
        # #     sch_grr_comp.SetPosition oDb2Position
        # #     set_position = oDb2Position
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rotation_angle(self, i_db1_rotation_angle_in_rad: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRotationAngle(double iDb1RotationAngleInRad)
                | 
                |     Set the current rotation angle (from x-axis in radian) of the
                |     component.
                | 
                |     Parameters:
                | 
                |         iDb1RotationAngleInRad
                |             The rotation angle of the component in radian to be set.
                |             
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRComp
                |          Dim dbVar As Double;
                |           ...
                |          objThisIntf.SetRotationAngledbVar

        :param float i_db1_rotation_angle_in_rad:
        :rtype: None
        """
        return self.sch_grr_comp.SetRotationAngle(i_db1_rotation_angle_in_rad)

    def set_scale(self, i_db1_scale_factor: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetScale(double iDb1ScaleFactor)
                | 
                |     Set the current scale factor of the component.
                | 
                |     Parameters:
                | 
                |         iDb1ScaleFactor
                |             The scale factor of the component to be set. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRComp
                |          Dim dbVar As Double;
                | 
                |           ...
                |          objThisIntf.SetScaledbVar

        :param float i_db1_scale_factor:
        :rtype: None
        """
        return self.sch_grr_comp.SetScale(i_db1_scale_factor)

    def set_transformation2_d(self, i_db6_trans_matrix: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTransformation2D(CATSafeArrayVariant
                | iDb6TransMatrix)
                | 
                |     Set the local coordinate reference frame (with respect to absolute
                |     coordinate system) of the component.
                | 
                |     Parameters:
                | 
                |         iDb6TransMatrix
                |             Transformation matrix to be set. See 
                | 
                |         GetTransformation2D for explanation of this argument. 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRComp
                |          Dim dbVar1(6) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.SetTransformation2DdbVar1

        :param tuple i_db6_trans_matrix:
        :rtype: tuple
        """
        return self.sch_grr_comp.SetTransformation2D(i_db6_trans_matrix)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_transformation2_d'
        # # vba_code = """
        # # Public Function set_transformation2_d(sch_grr_comp)
        # #     Dim iDb6TransMatrix (2)
        # #     sch_grr_comp.SetTransformation2D iDb6TransMatrix
        # #     set_transformation2_d = iDb6TransMatrix
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchGRRComp(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class VrmlSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         VrmlSettingAtt
                | 
                | The interface to access a CATIAVrmlSettingAtt.
                | This interface may be used to read or modify in the
                | CATIA\\Tools\\Option\\General\\Compatibility.... the settings values of the VRML
                | sheet.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.vrml_setting_att = com_object

    @property
    def export_edges(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ExportEdges() As boolean
                | 
                |     Returns or sets the ExportEdges parameter (exported Vrml files will or will
                |     not contains edge informations).
                | 
                |     Parameters:
                | 
                |         oExportEdges
                |             - iExportEdges Value of ExportEdges parameter. Legal
                |             values:
                |             TRUE : exported Vrml files will contain edge informations.
                |             FALSE : exported Vrml files will not contain edge informations.

        :rtype: bool
        """

        return self.vrml_setting_att.ExportEdges

    @export_edges.setter
    def export_edges(self, value: bool):
        """
        :param bool value:
        """

        self.vrml_setting_att.ExportEdges = value

    @property
    def export_normals(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ExportNormals() As boolean
                | 
                |     Returns or sets the ExportNormals parameter (exported Vrml files will or
                |     will not contains normal informations).
                | 
                |     Parameters:
                | 
                |         oExportNormals
                |             - iExportNormals Value of ExportNormals parameter. Legal
                |             values:
                |             TRUE : exported Vrml files will contain normal informations.
                |             FALSE : exported Vrml files will not contain normal informations.

        :rtype: bool
        """

        return self.vrml_setting_att.ExportNormals

    @export_normals.setter
    def export_normals(self, value: bool):
        """
        :param bool value:
        """

        self.vrml_setting_att.ExportNormals = value

    @property
    def export_texture(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ExportTexture() As boolean
                | 
                |     Returns or sets the ExportTexture parameter (exported Vrml files will or
                |     will not contains texture informations).
                | 
                |     Parameters:
                | 
                |         oExportTexture
                |             - iExportTexture Value of ExportTexture parameter. Legal
                |             values:
                |             TRUE : exported Vrml files will contain texture informations.
                |             FALSE : exported Vrml files will not contain texture informations.

        :rtype: bool
        """

        return self.vrml_setting_att.ExportTexture

    @export_texture.setter
    def export_texture(self, value: bool):
        """
        :param bool value:
        """

        self.vrml_setting_att.ExportTexture = value

    @property
    def export_texture_file(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ExportTextureFile() As long
                | 
                |     Returns or sets the ExportTextureFile parameter (Textures will be exported
                |     in the vrml file containing the geometry or in external
                |     files).
                | 
                |     Parameters:
                | 
                |         oExportTextureFile
                |             - iExportTextureFile Value of ExportTextureFile parameter. Legal
                |             values:
                |             0 : Textures are exported in the Vrml file containing the geometry.
                |             1 : Texture are exported in external files.

        :rtype: int
        """

        return self.vrml_setting_att.ExportTextureFile

    @export_texture_file.setter
    def export_texture_file(self, value: int):
        """
        :param int value:
        """

        self.vrml_setting_att.ExportTextureFile = value

    @property
    def export_texture_format(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ExportTextureFormat() As long
                | 
                |     Returns or sets the ExportTextureFormat parameter.
                | 
                |     Parameters:
                | 
                |         oExportTextureFormat
                |             - iExportTextureFormat Value of ExportTextureFormat parameter.
                |             Legal values:
                |             NOT APPLICABLE

        :rtype: int
        """

        return self.vrml_setting_att.ExportTextureFormat

    @export_texture_format.setter
    def export_texture_format(self, value: int):
        """
        :param int value:
        """

        self.vrml_setting_att.ExportTextureFormat = value

    @property
    def export_version(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ExportVersion() As long
                | 
                |     Returns or sets the ExportVersion parameter (version of exported Vrml
                |     files).
                | 
                |     Parameters:
                | 
                |         oExportVersion
                |             - iExportVersion Value of Import Unit parameter. Legal
                |             values:
                |             1 : VRML 1.0.
                |             2 : VRML 97 (VRML 2.0).

        :rtype: int
        """

        return self.vrml_setting_att.ExportVersion

    @export_version.setter
    def export_version(self, value: int):
        """
        :param int value:
        """

        self.vrml_setting_att.ExportVersion = value

    @property
    def import_crease_angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ImportCreaseAngle() As double
                | 
                |     Returns or sets the ImportCreaseAngle parameter. The crease angle affects
                |     how DEFAULT normals are generated. If the angle between the geometric normals
                |     of two adjacent faces is less than the crease angle, normals will be calculated
                |     so that the faces are smooth-shaded across the edge. Otherwise, normals will be
                |     calculated so that a lighting discontinuity across the edge is
                |     produce.
                | 
                |     Parameters:
                | 
                |         oImportCreaseAngle
                |             - iImportCreaseAngle Value of ImportCreaseAngle parameter. Legal
                |             values:
                |             [0,inf]

        :rtype: float
        """

        return self.vrml_setting_att.ImportCreaseAngle

    @import_crease_angle.setter
    def import_crease_angle(self, value: float):
        """
        :param float value:
        """

        self.vrml_setting_att.ImportCreaseAngle = value

    @property
    def import_unit(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ImportUnit() As long
                | 
                |     Returns or sets the ImportUnit parameter (unit of imported Vrml
                |     files).
                | 
                |     Parameters:
                | 
                |         oImportUnit
                |             - iImportUnit Value of Import Unit parameter. Legal
                |             values:
                |             0 : Millimeter.
                |             1 : Centimeter.
                |             2 : Meter.

        :rtype: int
        """

        return self.vrml_setting_att.ImportUnit

    @import_unit.setter
    def import_unit(self, value: int):
        """
        :param int value:
        """

        self.vrml_setting_att.ImportUnit = value

    def get_export_background_color(self, io_r: int, io_g: int, io_b: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetExportBackgroundColor(long ioR,
                | long ioG,
                | long ioB)
                | 
                |     Returns the ExportBackgroundColor parameter (Background color of exported
                |     Vrml files). Value of ExportBackgroundColor parameter. Legal
                |     values:
                |     R [0,255] G [0,255] B [0,255]

        :param int io_r:
        :param int io_g:
        :param int io_b:
        :rtype: None
        """
        return self.vrml_setting_att.GetExportBackgroundColor(io_r, io_g, io_b)

    def get_export_background_color_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetExportBackgroundColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the ExportBackgroundColor setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.vrml_setting_att.GetExportBackgroundColorInfo(io_admin_level, io_locked)

    def get_export_edges_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetExportEdgesInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the ExportEdges setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.vrml_setting_att.GetExportEdgesInfo(io_admin_level, io_locked)

    def get_export_normals_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetExportNormalsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the ExportNormals setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.vrml_setting_att.GetExportNormalsInfo(io_admin_level, io_locked)

    def get_export_texture_file_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetExportTextureFileInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the ExportTextureFile setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.vrml_setting_att.GetExportTextureFileInfo(io_admin_level, io_locked)

    def get_export_texture_format_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetExportTextureFormatInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the ExportTextureFormat setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.vrml_setting_att.GetExportTextureFormatInfo(io_admin_level, io_locked)

    def get_export_texture_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetExportTextureInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the ExportTexture setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.vrml_setting_att.GetExportTextureInfo(io_admin_level, io_locked)

    def get_export_version_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetExportVersionInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the ExportVersion setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.vrml_setting_att.GetExportVersionInfo(io_admin_level, io_locked)

    def get_import_crease_angle_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetImportCreaseAngleInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the ImportCreaseAngle setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.vrml_setting_att.GetImportCreaseAngleInfo(io_admin_level, io_locked)

    def get_import_unit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetImportUnitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the ImportUnit setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.vrml_setting_att.GetImportUnitInfo(io_admin_level, io_locked)

    def set_export_background_color(self, i_r: int, i_g: int, i_b: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetExportBackgroundColor(long iR,
                | long iG,
                | long iB)
                | 
                |     Sets the ExportBackgroundColor parameter (Background color of exported Vrml
                |     files). Value of ExportBackgroundColor parameter. Legal
                |     values:
                |     R [0,255] G [0,255] B [0,255]

        :param int i_r:
        :param int i_g:
        :param int i_b:
        :rtype: None
        """
        return self.vrml_setting_att.SetExportBackgroundColor(i_r, i_g, i_b)

    def set_export_background_color_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetExportBackgroundColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the ExportBackgroundColor setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.vrml_setting_att.SetExportBackgroundColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_background_color_lock'
        # # vba_code = """
        # # Public Function set_export_background_color_lock(vrml_setting_att)
        # #     Dim iLocked (2)
        # #     vrml_setting_att.SetExportBackgroundColorLock iLocked
        # #     set_export_background_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_edges_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetExportEdgesLock(boolean iLocked)
                | 
                |     Locks or unlocks the ExportEdges setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.vrml_setting_att.SetExportEdgesLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_edges_lock'
        # # vba_code = """
        # # Public Function set_export_edges_lock(vrml_setting_att)
        # #     Dim iLocked (2)
        # #     vrml_setting_att.SetExportEdgesLock iLocked
        # #     set_export_edges_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_normals_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetExportNormalsLock(boolean iLocked)
                | 
                |     Locks or unlocks the ExportNormals setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.vrml_setting_att.SetExportNormalsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_normals_lock'
        # # vba_code = """
        # # Public Function set_export_normals_lock(vrml_setting_att)
        # #     Dim iLocked (2)
        # #     vrml_setting_att.SetExportNormalsLock iLocked
        # #     set_export_normals_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_texture_file_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetExportTextureFileLock(boolean iLocked)
                | 
                |     Locks or unlocks the ExportTextureFile setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.vrml_setting_att.SetExportTextureFileLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_texture_file_lock'
        # # vba_code = """
        # # Public Function set_export_texture_file_lock(vrml_setting_att)
        # #     Dim iLocked (2)
        # #     vrml_setting_att.SetExportTextureFileLock iLocked
        # #     set_export_texture_file_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_texture_format_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetExportTextureFormatLock(boolean iLocked)
                | 
                |     Locks or unlocks the ExportTextureFormat setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.vrml_setting_att.SetExportTextureFormatLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_texture_format_lock'
        # # vba_code = """
        # # Public Function set_export_texture_format_lock(vrml_setting_att)
        # #     Dim iLocked (2)
        # #     vrml_setting_att.SetExportTextureFormatLock iLocked
        # #     set_export_texture_format_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_texture_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetExportTextureLock(boolean iLocked)
                | 
                |     Locks or unlocks the ExportTexture setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.vrml_setting_att.SetExportTextureLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_texture_lock'
        # # vba_code = """
        # # Public Function set_export_texture_lock(vrml_setting_att)
        # #     Dim iLocked (2)
        # #     vrml_setting_att.SetExportTextureLock iLocked
        # #     set_export_texture_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_version_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetExportVersionLock(boolean iLocked)
                | 
                |     Locks or unlocks the ExportVersion setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.vrml_setting_att.SetExportVersionLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_version_lock'
        # # vba_code = """
        # # Public Function set_export_version_lock(vrml_setting_att)
        # #     Dim iLocked (2)
        # #     vrml_setting_att.SetExportVersionLock iLocked
        # #     set_export_version_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_crease_angle_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetImportCreaseAngleLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportCreaseAngle setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.vrml_setting_att.SetImportCreaseAngleLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_crease_angle_lock'
        # # vba_code = """
        # # Public Function set_import_crease_angle_lock(vrml_setting_att)
        # #     Dim iLocked (2)
        # #     vrml_setting_att.SetImportCreaseAngleLock iLocked
        # #     set_import_crease_angle_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_unit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetImportUnitLock(boolean iLocked)
                | 
                |     Locks or unlocks the ImportLock setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.vrml_setting_att.SetImportUnitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_unit_lock'
        # # vba_code = """
        # # Public Function set_import_unit_lock(vrml_setting_att)
        # #     Dim iLocked (2)
        # #     vrml_setting_att.SetImportUnitLock iLocked
        # #     set_import_unit_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'VrmlSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.part import Part
from pycatia.system_interfaces.any_object import AnyObject


class SDDProduct(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SddProduct
                | 
                | Interface to create a SDD Design Unit under a Product.
                | Role: Allows creating Design Unit under a Product.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sdd_product = com_object

    def create_design_unit(self) -> Part:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateDesignUnit() As Part
                | 
                |     Creates the Design Unit inside a Product.
                | 
                |     Example:
                |
                |              This Example creates a Design Unit inside a Product from
                |              scratch.
                |
                |              ' Create a New Product Document
                |              Dim NewProdDoc As ProductDocument
                |              Set NewProdDoc = CATIA.Documents.Add("Product")
                |              ' Get the Product from the Product Document
                |              Dim RootPrd As Product
                |              Set RootPrd = NewProdDoc.Product
                |              ' Select the Product Document and Add the product to this
                |              selection
                |              Dim SelectionObj As Selection
                |              Set SelectionObj = NewProdDoc.Selection
                |              SelectionObj.Add RootPrd
                |              ' Create a SDD product from above Product
                |              Dim SddProductObj As SddProduct
                |              Set SddProductObj = SelectionObj.FindObject("CATIASddProduct")
                |              ' Create a Design Unit under this Product
                |              Dim SddDesignUnit As Part
                |              Set SddDesignUnit = SddProductObj.CreateDesignUnit
                |              ' Using this Part get the CustomerFactory
                |              Dim FactoryObj As SfmFactory
                |              Set FactoryObj = SddDesignUnit.GetCustomerFactory("SfmFactory")

        :rtype: Part
        """
        return Part(self.sdd_product.CreateDesignUnit())

    def __repr__(self):
        return f'SDDProduct(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_field_output_request import ABQFieldOutputRequest
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQFieldOutputRequests(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQFieldOutputRequests
                | 
                | The collection of Abaqus field output request (ABQFieldOutputRequest) objects
                | attached to an
                | ABQGeneralStaticStep, an ABQFrequencyStep, an ABQHeatTransferStep, or an
                | ABQExplicitDynamicsStep object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ABQFieldOutputRequest)
        self.abq_field_output_requests = com_object

    def add(self) -> ABQFieldOutputRequest:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As ABQFieldOutputRequest
                | 
                |     Creates a new Abaqus field output request and adds it to the collection of
                |     Abaqus field output requests.
                | 
                |     Returns:
                |         oFieldOutputRequest The Abaqus field output request object that was
                |         created. 
                |     Example:
                |         The following example creates a field output request in the
                |         ABQFieldOutputRequests collection:
                | 
                |          Dim abqFieldOutputRequests As ABQFieldOutputRequests
                |          Set abqFieldOutputRequests = generalstaticstep.FieldOutputRequests
                |          Dim abqFieldOutputRequest As ABQFieldOutputRequest
                |          Set abqFieldOutputRequest =  abqFieldOutputRequests.Add()

        :rtype: ABQFieldOutputRequest
        """
        return ABQFieldOutputRequest(self.abq_field_output_requests.Add())

    def item(self, i_index: cat_variant) -> ABQFieldOutputRequest:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ABQFieldOutputRequest
                | 
                |     Returns an Abaqus field output request using its index or its name from the
                |     ABQFieldOutputRequests collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus field output request to
                |             retrieve from the collection of Abaqus field output requests. If the index is a
                |             number, it specifies the rank of the Abaqus field output request in the
                |             collection. The index of the first Abaqus field output request in the
                |             collection is 1, and the index of the last field output request is Count. If
                |             the index is a string, it specifies the name you assigned to the field output
                |             request using the CATIACollection::Name property. 
                | 
                |     Returns:
                |         The specified ABQFieldOutputRequest.

        :param cat_variant i_index:
        :rtype: ABQFieldOutputRequest
        """
        return ABQFieldOutputRequest(self.abq_field_output_requests.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes an Abaqus field output request using its index or its name from the
                |     field output requests collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the field output request to retrieve from
                |             the collection of field output requests. As a numeric, this index is the rank
                |             of the field output request in the collection. The index of the first field
                |             output request in the collection is 1, and the index of the last field output
                |             request is Count. As a string, it is the name you assigned to the field output
                |             request using the CATIABase::Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.abq_field_output_requests.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(abq_field_output_requests)
        # #     Dim iIndex (2)
        # #     abq_field_output_requests.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQFieldOutputRequests(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.in_interfaces.references import References
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.system_interfaces.any_object import AnyObject


class DraftDomain(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DraftDomain
                | 
                | Represents the draft domain.
                | A draft domain is a basic object used by a draft shape. It contains objects
                | such as an angle, a pulling direction, and a collection of faces to be
                | drafted.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.draft_domain = com_object

    @property
    def draft_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DraftAngle() As Angle (Read Only)
                | 
                |     Returns the draft angle.
                | 
                |     Example:
                |         The following example returns in angle the draft angle of the draft
                |         domain firstDraftDomain:
                | 
                |          Set angle = firstDraftDomain.DraftAngle

        :rtype: Angle
        """

        return Angle(self.draft_domain.DraftAngle)

    @property
    def faces_to_draft(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FacesToDraft() As References (Read Only)
                | 
                |     Returns the faces to be drafted. They are returned as a collection of
                |     reference geometric elements.
                | 
                |     Example:
                |         The following example returns the collection of faces to be drafted of
                |         the draft domain firstDraftDomain in list:
                | 
                |          Set list = firstDraftDomain.FacesToDraft

        :rtype: References
        """

        return References(self.draft_domain.FacesToDraft)

    @property
    def multiselection_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MultiselectionMode() As CatDraftMultiselectionMode
                | 
                |     Changes the multiselection mode.
                | 
                |     Parameters:
                | 
                |         iMultiselectionMode.
                |             The elements to be drafted can be selected explicitly
                |             (CATNoneDraftMultiselectionMode) or can implicitly selected as neighbors of the
                |             neutral face (CATMultiselectionByNeutralMode)
                | 
                |             Example:
                |                 The following example returns in MultiselMode the
                |                 multiselection mode of the draft domain firstDraftDomain, and then sets it to
                |                 CATMultiselectionByNeutralMode
                | 
                |                  Set MultiselMode = firstDraftDomain.MultiselectionMode
                |                  firstDraftDomain.MultiselectionMode = CATMultiselectionByNeutralMode

        :return: enum cat_draft_multiselection_mode
        :rtype: int
        """

        return self.draft_domain.MultiselectionMode

    @multiselection_mode.setter
    def multiselection_mode(self, value: int):
        """
        :param int value: enum cat_draft_multiselection_mode
        """

        self.draft_domain.MultiselectionMode = value

    @property
    def neutral_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property NeutralElement() As Reference
                | 
                |     Returns or sets the draft neutral element.
                |     To set the property, you can use the following Boundary object:
                |     PlanarFace.
                | 
                |     Example:
                |         The following example returns in neutral the neutral element of the
                |         draft domain firstDraftDomain, and then sets it to
                |         newNeutral:
                | 
                |          Set neutral = firstDraftDomain.NeutralElement
                |          firstDraftDomain.NeutralElement = newNeutral

        :rtype: Reference
        """

        return Reference(self.draft_domain.NeutralElement)

    @neutral_element.setter
    def neutral_element(self, value: Reference):
        """
        :param Reference value:
        """

        self.draft_domain.NeutralElement = value.com_object

    @property
    def neutral_propagation_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property NeutralPropagationMode() As
                | CatDraftNeutralPropagationMode
                | 
                |     Returns or sets the neutral element propagation mode. This mode is used
                |     when computing the needed neutral elements.
                | 
                |     Example:
                |         The following example returns in propMode the neutral propagation mode
                |         of the draft domain firstDraftDomain, and then sets it to
                |         CATSmoothDraftNeutralPropagationMode so that the neutral propagation will now
                |         be smooth:
                | 
                |          Set propMode = firstDraftDomain.NeutralPropagationMode
                |          firstDraftDomain.NeutralPropagationMode = CATSmoothDraftNeutralPropagationMode

        :return: enum cat_draft_neutral_propagation_mode
        :rtype: int
        """

        return self.draft_domain.NeutralPropagationMode

    @neutral_propagation_mode.setter
    def neutral_propagation_mode(self, value: int):
        """
        :param int value: enum cat_draft_neutral_propagation_mode
        """

        self.draft_domain.NeutralPropagationMode = value

    @property
    def pulling_direction_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PullingDirectionElement() As Reference
                | 
                |     Returns or sets the draft pulling direction element.
                |     To set the property, you can use one of the following Boundary objects:
                |     PlanarFace or RectilinearTriDimFeatEdge.
                | 
                |     Example:
                |         The following example returns in pullingdirection the pulling direction
                |         element of the draft domain firstDraftDomain, and then sets it to
                |         newPullingDirection:
                | 
                |          Set pullingdirection = firstDraftDomain.NeutralElement
                |          firstDraftDomain.PullingDirectionElement = newPullingDirection

        :rtype: Reference
        """

        return Reference(self.draft_domain.PullingDirectionElement)

    @pulling_direction_element.setter
    def pulling_direction_element(self, value: Reference):
        """
        :param Reference value:
        """

        self.draft_domain.PullingDirectionElement = value.com_object

    def add_face_to_draft(self, i_face: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddFaceToDraft(Reference iFace)
                | 
                |     Adds a face to those to be drafted.
                | 
                |     Parameters:
                | 
                |         iFace
                |             The face to add to those to be drafted
                |             The following 
                | 
                |         Boundary object is supported: ScFace. 
                | 
                | Example:
                |     The following example adds the face NewFaceToDraft to the draft domain
                |     CurrentDraftDomain:
                | 
                |      CurrentDraftDomain.AddFaceToDraft(NewFaceToDraft)

        :param Reference i_face:
        :rtype: None
        """
        return self.draft_domain.AddFaceToDraft(i_face.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_face_to_draft'
        # # vba_code = """
        # # Public Function add_face_to_draft(draft_domain)
        # #     Dim iFace (2)
        # #     draft_domain.AddFaceToDraft iFace
        # #     add_face_to_draft = iFace
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_pulling_direction(self, io_pulling_direction: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetPullingDirection(CATSafeArrayVariant
                | ioPullingDirection)
                | 
                |     Returns the draft pulling direction. The pulling direction is returned as
                |     an array containing the pulling direction vector components. Assume this array
                |     is PullDir. It contains:
                | 
                |     PullDir[0],PullDir[1],PullDir[2]
                |         The X, Y, and Z pulling direction vector components 
                | 
                |     Example:
                |         The following example returns in PullDir the pulling direction vector
                |         components of the draft domain firstDraftDomain:
                | 
                |          Set PullDir = firstDraftDomain.PullingDirection
                |          Set x = PullDir[0]
                |          Set y = PullDir[1]
                |          Set z = PullDir[2]

        :param tuple io_pulling_direction:
        :rtype: None
        """
        return self.draft_domain.GetPullingDirection(io_pulling_direction)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_pulling_direction'
        # # vba_code = """
        # # Public Function get_pulling_direction(draft_domain)
        # #     Dim ioPullingDirection (2)
        # #     draft_domain.GetPullingDirection ioPullingDirection
        # #     get_pulling_direction = ioPullingDirection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_face_to_draft(self, i_face: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveFaceToDraft(Reference iFace)
                | 
                |     Removes a face from those to be drafted.
                | 
                |     Parameters:
                | 
                |         iFace
                |             The face to be removed from those to be drafted
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                | 
                | Example:
                |     The following example removes the face FaceToRemove from the draft domain
                |     CurrentDraftDomain:
                | 
                |      CurrentDraftDomain.RemoveFaceToDraft(FaceToRemove)

        :param Reference i_face:
        :rtype: None
        """
        return self.draft_domain.RemoveFaceToDraft(i_face.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_face_to_draft'
        # # vba_code = """
        # # Public Function remove_face_to_draft(draft_domain)
        # #     Dim iFace (2)
        # #     draft_domain.RemoveFaceToDraft iFace
        # #     remove_face_to_draft = iFace
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_pulling_direction(self, i_x: float, i_y: float, i_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPullingDirection(double iX,
                | double iY,
                | double iZ)
                | 
                |     Sets the draft pulling direction.
                | 
                |     Parameters:
                | 
                |         iX,iY,iZ
                |             The X, Y, and Z pulling direction vector components
                |             
                | 
                |     Example:
                |         The following example sets the draft pulling direction of the draft
                |         domain firstDraftDomain to the direction with the vector components 10, -5,
                |         10:
                | 
                |          firstDraftDomain.PullingDirection 10, -5, 10

        :param float i_x:
        :param float i_y:
        :param float i_z:
        :rtype: None
        """
        return self.draft_domain.SetPullingDirection(i_x, i_y, i_z)

    def set_volume_support(self, i_volume_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetVolumeSupport(Reference iVolumeSupport)
                | 
                |     Value the support of draft.
                | 
                |     Parameters:
                | 
                |         iVolumeSupport

        :param Reference i_volume_support:
        :rtype: None
        """
        return self.draft_domain.SetVolumeSupport(i_volume_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_volume_support'
        # # vba_code = """
        # # Public Function set_volume_support(draft_domain)
        # #     Dim iVolumeSupport (2)
        # #     draft_domain.SetVolumeSupport iVolumeSupport
        # #     set_volume_support = iVolumeSupport
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DraftDomain(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_list_of_doubles import PSPListOfDoubles
from pycatia.cat_plant_ship_interfaces.psp_list_of_objects import PSPListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class PSPPlacePart(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspPlacePart
                | 
                | Represents the Place physical parts object.
                | Role: To place physical parts.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_place_part = com_object

    @property
    def error_message(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ErrorMessage() As CATBSTR (Read Only)
                | 
                |     Returns the message associated with the last error.
                |     Role: If an error occurs when placing or routing a part, a message is
                |     associated with the error.
                | 
                |     Returns:
                |         The error message associated with the last error. Null if no error.

        :rtype: str
        """

        return self.psp_place_part.ErrorMessage

    def place_part_in_space(
            self,
            iu_standard: str,
            iu_function_type: str,
            ipi_reference_part: AnyObject,
            ipi_parent_product: AnyObject,
            ipi_logical_line: AnyObject,
            iu_placed_part_id: str,
            i_up_direction: PSPListOfDoubles,
            i_horizontal_orientation: PSPListOfDoubles,
            i_position: PSPListOfDoubles
    ) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func PlacePartInSpace(CATBSTR iuStandard,
                | CATBSTR iuFunctionType,
                | AnyObject ipiReferencePart,
                | AnyObject ipiParentProduct,
                | AnyObject ipiLogicalLine,
                | CATBSTR iuPlacedPartID,
                | PspListOfDoubles iUpDirection,
                | PspListOfDoubles iHorizontalOrientation,
                | PspListOfDoubles iPosition) As AnyObject
                | 
                |     Places a part in space.
                |     Role: The part instance is placed given its reference with respect to its
                |     parent product. The Part Placement engine will not perform any of it's normal
                |     checks for interactions with nearby parts. Part is placed
                |     non-spec.
                | 
                |     Parameters:
                | 
                |         iuStandard
                |             The standard for application attribute values. 
                |         iuFunctionType
                |             The type of function (e.g. block valve, branch). Used when no
                |             function is specified but functional part placement is required.
                |             
                |         ipiReferencePart
                |             The reference part from which to derive the instance part.
                |             
                |         ipiParentProduct
                |             The parent product (in the design model) for the new instance part.
                |             
                |         ipiLogicalLine
                |             The logical line (e.g. piping line) which contains the instance
                |             part. 
                |         iuPlacedPartID
                |             The name of the placed part in the design model. Null uses the
                |             standard ID generated by the part placement engine.
                |             
                |         iUpDirection
                |             The up direction for the placed part. The list has three values
                |             which represent the x, y and z values of a unit direction vector. Value is
                |             relative to ipiParentProduct. 
                |         iHorizontalOrientation
                |             The orientation of the part in "horizontal" plane (plane
                |             perpendicular to up direction). Must be perpendicular to iUpDirection. The list
                |             has three values which represent the x, y and z values of a unit direction
                |             vector. Value is relative to ipiParentProduct. 
                |         iPosition
                |             The position of the part. The list has three values which represent
                |             the x, y and z values of a position in space. Value is relative to
                |             ipiParentProduct and expressed in millimeters. 
                | 
                |     Returns:
                |         The placed instance part.

        :param str iu_standard:
        :param str iu_function_type:
        :param AnyObject ipi_reference_part:
        :param AnyObject ipi_parent_product:
        :param AnyObject ipi_logical_line:
        :param str iu_placed_part_id:
        :param PSPListOfDoubles i_up_direction:
        :param PSPListOfDoubles i_horizontal_orientation:
        :param PSPListOfDoubles i_position:
        :rtype: AnyObject
        """
        return AnyObject(
            self.psp_place_part.PlacePartInSpace(
                iu_standard,
                iu_function_type,
                ipi_reference_part.com_object,
                ipi_parent_product.com_object,
                ipi_logical_line.com_object,
                iu_placed_part_id,
                i_up_direction.com_object,
                i_horizontal_orientation.com_object,
                i_position.com_object
            )
        )

    def route_string_part_in_space(
            self,
            iu_standard: str,
            iu_function_type: str,
            ipi_reference_part: AnyObject,
            ipi_parent_product: AnyObject,
            ipi_logical_line: AnyObject,
            iu_placed_part_id: str,
            i_first_point_up_direction: PSPListOfDoubles,
            ipi_list_points: PSPListOfObjects,
            i_list_bend_radii: PSPListOfDoubles
    ) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func RouteStringPartInSpace(CATBSTR iuStandard,
                | CATBSTR iuFunctionType,
                | AnyObject ipiReferencePart,
                | AnyObject ipiParentProduct,
                | AnyObject ipiLogicalLine,
                | CATBSTR iuPlacedPartID,
                | PspListOfDoubles iFirstPointUpDirection,
                | PspListOfObjects ipiListPoints,
                | PspListOfDoubles iListBendRadii) As AnyObject
                | 
                |     Routes a string part.
                |     Role: The string part instance, such as a pipe, a tube, or a duct, is
                |     placed given its reference with respect to its parent product. The Part
                |     Placement engine will not perform any of it's normal checks for interactions
                |     with nearby parts. Part is placed non-spec.
                | 
                |     Parameters:
                | 
                |         iuStandard
                |             The standard for application attribute values. 
                |         iuFunctionType
                |             The type of function (e.g. Block valve, branch). Used when no
                |             function is specified but functional part placement is required.
                |             
                |         ipiReferencePart
                |             The reference part from which to derive the instance part.
                |             
                |         ipiParentProduct
                |             The parent product (in the design model) for the new instance part.
                |             
                |         ipiLogicalLine
                |             The logical line (e.g. piping line) which contains the instance
                |             part. 
                |         iuPlacedPartID
                |             The name of the placed part in the design model. Null uses the
                |             standard ID generated by the part placement engine.
                |             
                |         iFirstPointUpDirection
                |             The up direction of the first point of the string part. The list
                |             has three values which represent the x, y and z values of a unit direction
                |             vector. Value is relative to ipiParentProduct. 
                |         ipiListPoints
                |             The list of points that describe the path of the string. If the
                |             string part is stretchable, the list should contain two points.
                |             
                |         iListBendRadii
                |             The list of bend radii at each corner of the string part. This list
                |             is ignored if the string part is stretchable. This list is only for interior
                |             points and so should have two less elements than ipiListPoints. (for example,
                |             if ipiListPoints has six points, iListBendRadii should have four radii values).
                |             Values are in milimeters. 
                | 
                |     Returns:
                |         The routed string part.

        :param str iu_standard:
        :param str iu_function_type:
        :param AnyObject ipi_reference_part:
        :param AnyObject ipi_parent_product:
        :param AnyObject ipi_logical_line:
        :param str iu_placed_part_id:
        :param PSPListOfDoubles i_first_point_up_direction:
        :param PSPListOfObjects ipi_list_points:
        :param PSPListOfDoubles i_list_bend_radii:
        :rtype: AnyObject
        """
        return AnyObject(
            self.psp_place_part.RouteStringPartInSpace(
                iu_standard,
                iu_function_type,
                ipi_reference_part.com_object,
                ipi_parent_product.com_object,
                ipi_logical_line.com_object,
                iu_placed_part_id,
                i_first_point_up_direction.com_object,
                ipi_list_points.com_object,
                i_list_bend_radii.com_object
            )
        )

    def __repr__(self):
        return f'PSPPlacePart(name="{self.name}")'
